@@ -87,7 +87,7 @@ update.DSF_ExponentialMA <- function(object,
   if (is.null(dsd))
     dsd <- object$dsd
   if (is.null(dsd))
-    stop("No dsd specified in ", deparse(substitute(object)), ". Specify a dsd in update().")
+    stop("No dsd specified in ", deparse1(substitute(object)), ". Specify a dsd in update().")
 
   if (n == 0)
     return(get_points(dsd, n = 0L, info = info))
@@ -100,7 +100,7 @@ update.DSF_ExponentialMA <- function(object,
   if (is.null(object$S.env$S))
     object$S.env$S <- d[1, dims, drop = FALSE]
 
-  for (i in seq(nrow(d))) {
+  for (i in seq_len(nrow(d))) {
     # handle NA
     Y <- d[i, dims, drop = FALSE]
     if (any(missing <- is.na(Y)))
