@@ -17,22 +17,22 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #' @rdname MGC
-MGC_Static <- function(density = 1, center, parameter,
-  shape = NULL) {
-    if(is.null(shape)) shape <- MGC_Shape_Gaussian
-
-    x <- MGC_Function(
-      density = function(t) density,
-      parameter = function(t) parameter,
-      center= function(t) center,
-      shape = shape
-    )
+#' @export
+MGC_Static <- function(density = 1,
+  center,
+  parameter,
+  shape = Shape_Gaussian) {
+  x <- MGC_Function(
+    density = function(t)
+      density,
+    parameter = function(t)
+      parameter,
+    center = function(t)
+      center,
+    shape = shape
+  )
 
   x$description <- "Static Cluster"
-
   class(x) <- c("MGC_Static", class(x))
   x
 }
-
-
-
